### Name: diveMove-package
### Title: Time depth recorder analysis
### Aliases: diveMove-package diveMove
### Keywords: package

### ** Examples

## read in data and create a TDR object
(sealX <- readTDR(system.file(file.path("data", "sealMK8.csv"),
                              package="diveMove")))
## Not run: 
##D plot(sealX)  # pan and zoom through the record
## End(Not run)

## detect periods of activity, and calibrate depth, creating
## a 'TDRcalibrate' object
## Not run: dcalib <- calibrateDepth(sealX) # interactively
(dcalib <- calibrateDepth(sealX, offset=3)) # zero-offset correct at 3 m

## Not run: 
##D ## plot all readings and label them with the phase of the record
##D ## they belong to, excluding surface readings
##D plot(dcalib, labels="phase.id", surface=FALSE)
##D ## plot the first 300 dives, showing dive phases and surface readings
##D plot(dcalib, diveNo=seq(300), labels="dive.phase", surface=TRUE)
## End(Not run)

## calibrate speed (using default remaining arguments)
(vcalib <- calibrateSpeed(dcalib))

## Obtain dive statistics for all dives detected
dives <- diveStats(vcalib)
head(dives)

## Attendance table
att <- attendance(vcalib, FALSE) # taking trivial aquatic activities into account
att <- attendance(vcalib, TRUE)  # ignoring them
## Add trip stamps to each dive
stamps <- stampDive(vcalib)
sumtab <- data.frame(stamps, dives)
head(sumtab)



